/**
 * Creating a sidebar enables you to:
 - create an ordered group of docs
 - render a sidebar for each doc of that group
 - provide next/previous navigation

 The sidebars can be generated from the filesystem, or explicitly defined here.

 Create as many sidebars as you want.
 */

// @ts-check

/** @type {import('@docusaurus/plugin-content-docs').SidebarsConfig} */
const sidebars = {
  // By default, Docusaurus generates a sidebar from the docs folder structure
  guide: [
    {
      type: "category",
      label: "开始",
      collapsible: false,
      items: [
        "guide/index",
        "guide/installation",
        "guide/getting-started",
        "guide/creating-a-project",
        "guide/basic-configuration",
      ],
    },
    {
      type: "category",
      label: "编写插件",
      collapsible: false,
      items: [
        "guide/loading-a-plugin",
        "guide/creating-a-plugin",
        "guide/creating-a-matcher",
        "guide/creating-a-handler",
        "guide/end-or-start",
      ],
    },
    {
      type: "category",
      label: "协议适配",
      collapsible: false,
      items: [
        "guide/cqhttp-guide",
        "guide/ding-guide",
        "guide/mirai-guide",
        "guide/feishu-guide",
      ],
    },
  ],
  advanced: [
    {
      type: "category",
      label: "进阶",
      collapsible: false,
      items: [
        "advanced/index",
        "advanced/scheduler",
        "advanced/permission",
        "advanced/runtime-hook",
        "advanced/export-and-require",
        "advanced/overloaded-handlers",
      ],
    },
    {
      type: "category",
      label: "发布",
      collapsible: false,
      items: ["advanced/publish-plugin"],
    },
  ],
  api: [{ type: "autogenerated", dirName: "api" }],

  // But you can create a sidebar manually
  /*
  tutorialSidebar: [
    {
      type: 'category',
      label: 'Tutorial',
      items: ['hello'],
    },
  ],
   */
};

module.exports = sidebars;
